@@ -64,6 +64,18 @@ class PersistentState:
             f.write(contents)
 
 
+def get_device_serial(address):
+    device_info_endpoint = f"http://{address}/api/sysinfo/v1.0/device"
+    try:
+        response = requests.get(device_info_endpoint, timeout=5)
+        if response:
+            return response.json()['uuid']
+        else:
+            return None
+    except Exception as e:
+        return None
+
+
 def check_for_updates(persistent_state):
     last_update_check_time = persistent_state.get('last_update_check_time', 0)
     current_time = time.time()
